@@ -1,51 +1,10 @@
 #!/usr/bin/python
 # -*- coding: iso-8859-15 -*-
 """
-GPS time/date management
+GNSS time/date management
 Beilin Jacques
 ENSG/IGN
 
-2015-08-05 JBL
-    1. utilisation du module decimal pour gerer les multiplications grands nombres /
-    grande precision
-2015-10-02 JBL
-    1. utilisation du module Decimal dans add_s, add_h et add_day
-2015-12-26 JBL
-    1. creation d'un getter/setter pour wsec pour gerer le passage decimal/float
-2016-06-14 1.0.14 JBL
-    1. ajout d'une sortie au format pyephem pour les calcul d'azimut par le soleil
-2016-06-15 1.0.15 JBL
-    1. gestion de l'affichage de l'aide
-2016-06-27 1.0.16 JBL
-    1. ajouts des fonctions snx_t et st_snx_epoch : entre/sortie en date sinex
-2016-06-28 1.0.17 JBL
-    1. ajout de return  toutes les fonctions xx00 et add_x pour pouvoir les enchainer
-????-??-?? 1.0.18 JBL
-    1. ?
-2017-01-07 1.0.19 JBL
-    1. ajout de 2 fonction pour surcharger += et - =  pour ajouter ou enlever des secondes
-     un objet gpsdatetime
-    2. modification des fonctions print. Il est maintenant possible d'crire print(t),
-    t.print() ou t.print_dates() pour avoir toutes les infos en meme temps
-2017-01-07 1.0.20 JBL
-    1. Possibilite d'initialiser directement l'objet  une date donne en mjd ou ymd
-    ou ymdhms ou just_now...
-2017-01-08 1.0.21 JBL
-    2. amelioration du constructeur
-2017-01-08 1.0.22 JBL
-    2. amelioration du constructeur
-2017-01-08 1.0.23 JBL
-    2. amelioration du constructeur (snx, iso, rinex, jd, jd50)
-2017-03-14 1.0.24 JBL
-    1. constructeur : h, m, s geres independemment
-2017-03-14 1.0.25 JBL
-    1. constructeur : h, m, s geres independemment y compris pour init a partir de wk/wd
-2018-10-12 1.0.26 JBL
-    1. possibilite de construire une copie d'un objet gpsdatetime
-    sans passer par copy.copy t2 = gpsdatetime(t1)
-2018-10-22
-    1. init par string iso
-    2. init par string rinex '18 10  9 12 20 45.00000'
 """
 
 import re
@@ -77,6 +36,7 @@ class gpsdatetime():
 
     _re_iso = '^[12][0-9][0-9][0-9]-[01][0-9]-[0123][0-9]T[012][0-9]:[0-5][0-9]:[0-5][0-9](\.\d+)?Z$'
     _re_rnx = '^[0-9][0-9] [ 01][0-9] [ 0123][0-9] [ 012][0-9] [ 0-5][0-9] [ 0-5][0-9](\.\d+)?$'
+    _re_rnx3 = '^[0-9][0-9][0-9][0-9] [ 01][0-9] [ 0123][0-9] [ 012][0-9] [ 0-5][0-9] [ 0-5][0-9](\.\d+)?$'
     _re_snx = '^[0-9][0-9]:[0123][0-9][0-9]:[0-8][0-9][0-9][0-9][0-9]$'
 
     def __init__(self, *args, **kwargs):
@@ -96,6 +56,10 @@ class gpsdatetime():
                 if re.search(gpsdatetime._re_rnx, args[0]):
                     self.rinex_t(args[0])
                     return
+                
+                if re.search(gpsdatetime._re_rnx3, args[0]):
+                    self.rinex_t(args[0])
+                    return
 
 #                print(" >  >  >  >  > "+s)
 #        for arg in args:
@@ -251,6 +215,10 @@ class gpsdatetime():
         self.s1970 = s1970 # secondes a partir de 1970-01-01
         #print("s1970 = ", s1970)
         T = tm.gmtime(float(s1970))
+        
+        Tloc = tm.localtime()
+        self.gmtoff = Tloc.tm_gmtoff
+        self.zone = Tloc.tm_zone
 
         a = decimal.Decimal(s1970)
         _decimal_sec = decimal.Decimal(a - math.floor(a))
@@ -609,6 +577,12 @@ class gpsdatetime():
         return "%4d/%02d/%02d %02d:%02d:%04.1f" \
                 % (self.yyyy, self.mon, self.dd, self.hh, self.min, self.sec)
 
+    def st_rinex_epoch(self):
+        """ return rinex time string
+        """
+        return "%4d %02d %02d %02d %02d %10.7f" \
+                % (self.yyyy, self.mon, self.dd, self.hh, self.min, self.sec)
+
     def st_snx_epoch(self):
         """ return SINEX time string
         """
@@ -711,9 +685,14 @@ if __name__ == "__main__":
 
     time_2 += 1000
 
-    time_3 = gpsdatetime('18 10  9 14 20 45.00000')
+    time_3 = gpsdatetime('18 10  9 14 20 00.00000')
     print(time_3)
+    time_3 = gpsdatetime('2018 10  9 14 20 00.00000')
+    print('>>>>', time_3)
 
     print(time_1.st_iso_epoch())
     print(time_2.st_iso_epoch())
+    
+    print(time_3.st_rinex_epoch())
+    
     
\ No newline at end of file
